==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Surveys/language/lang-slovenian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_YOURNAME","Vae ime");
define("_OK","V redu");
define("_COMMENT","komentar");
define("_CONFIGURE","Konfiguriraj");
define("_LOGINCREATE","Vstop/Izdelaj raun");
define("_THRESHOLD","Threshold");
define("_NOCOMMENTS","Brez komentarja");
define("_NESTED","Vgnezdeno");
define("_FLAT","Plosko");
define("_THREAD","Nit");
define("_OLDEST","Stareje");
define("_NEWEST","Noveje");
define("_HIGHEST","Z najvijim rezultatom");
define("_COMMENTSWARNING","Vsi komentarji so lastnitvo osebe, ki jih je napisala. Za njihovo vsebino ne odgovarjamo.");
define("_SCORE","Ocena:");
define("_USERINFO","Informacije o uporabniku");
define("_READREST","Preberi ostanek tega komentarja...");
define("_REPLY","Odgovori na to");
define("_REPLYMAIN","Komentiraj");
define("_NOSUBJECT","Brez naslova");
define("_NOANONCOMMENTS","Komentiranje anonimnim uporabnikom ni dovoljeno, <a href=\"modules.php?name=Your_Account\">registrirajte se</a>");
define("_PARENT","Parent");
define("_ROOT","Root");
define("_UCOMMENT","Komentar");
define("_ALLOWEDHTML","HTML koda je dovoljena:");
define("_POSTANON","Polji anonimno");
define("_EXTRANS","Extrans (html tag v tekstu)");
define("_HTMLFORMATED","HTML formatirano");
define("_PLAINTEXT","Normalen tekst");
define("_ONN","na...");
define("_SUBJECT","Naslov");
define("_SURVEYCOM","Odgovori na anketo");
define("_SURVEYCOMPRE","Pregled/preverjanje pred poiljanjem");
define("_NOTRIGHT","Nekaj ni v redu s prehodom variable ez to funkcijo. Smisel tega sporoila je reevanje mogoih napak");
define("_DIRECTCOM","Direktni komentar na anketo...");
define("_SENDAMSG","Polji sporoilo");
define("_PASTSURVEYS","Pretekle ankete");



define("_LVOTES","glasovi");
define("_TOTALVOTES","Skupno glasov:");
define("_VOTING","Glasovalni kot");
define("_OTHERPOLLS","Ostale ankete");
define("_CURRENTSURVEY","Trenutna anketa");
define("_CURRENTPOLLRESULTS","Trenutni rezultati ankete");
define("_PREVIEW","Pregled");
define("_REFRESH","Osvei");
define("_SURVEYS","Ankete");
define("_ATTACHEDTOARTICLE","- Prikljueno lanku:");
define("_SURVEYSATTACHED","Ankete prikljuene lankom");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Surveys/language/lang-slovenian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_YOURNAME","Vae ime");
define("_OK","V redu");
define("_COMMENT","komentar");
define("_CONFIGURE","Konfiguriraj");
define("_LOGINCREATE","Vstop/Izdelaj raun");
define("_THRESHOLD","Threshold");
define("_NOCOMMENTS","Brez komentarja");
define("_NESTED","Vgnezdeno");
define("_FLAT","Plosko");
define("_THREAD","Nit");
define("_OLDEST","Stareje");
define("_NEWEST","Noveje");
define("_HIGHEST","Z najvijim rezultatom");
define("_COMMENTSWARNING","Vsi komentarji so lastnitvo osebe, ki jih je napisala. Za njihovo vsebino ne odgovarjamo.");
define("_SCORE","Ocena:");
define("_USERINFO","Informacije o uporabniku");
define("_READREST","Preberi ostanek tega komentarja...");
define("_REPLY","Odgovori na to");
define("_REPLYMAIN","Komentiraj");
define("_NOSUBJECT","Brez naslova");
define("_NOANONCOMMENTS","Komentiranje anonimnim uporabnikom ni dovoljeno, <a href=\"modules.php?name=Your_Account\">registrirajte se</a>");
define("_PARENT","Parent");
define("_ROOT","Root");
define("_UCOMMENT","Komentar");
define("_ALLOWEDHTML","HTML koda je dovoljena:");
define("_POSTANON","Polji anonimno");
define("_EXTRANS","Extrans (html tag v tekstu)");
define("_HTMLFORMATED","HTML formatirano");
define("_PLAINTEXT","Normalen tekst");
define("_ONN","na...");
define("_SUBJECT","Naslov");
define("_SURVEYCOM","Odgovori na anketo");
define("_SURVEYCOMPRE","Pregled/preverjanje pred poiljanjem");
define("_NOTRIGHT","Nekaj ni v redu s prehodom variable ez to funkcijo. Smisel tega sporoila je reevanje mogoih napak");
define("_DIRECTCOM","Direktni komentar na anketo...");
define("_SENDAMSG","Polji sporoilo");
define("_PASTSURVEYS","Pretekle ankete");



define("_LVOTES","glasovi");
define("_TOTALVOTES","Skupno glasov:");
define("_VOTING","Glasovalni kot");
define("_OTHERPOLLS","Ostale ankete");
define("_CURRENTSURVEY","Trenutna anketa");
define("_CURRENTPOLLRESULTS","Trenutni rezultati ankete");
define("_PREVIEW","Pregled");
define("_REFRESH","Osvei");
define("_SURVEYS","Ankete");
define("_ATTACHEDTOARTICLE","- Prikljueno lanku:");
define("_SURVEYSATTACHED","Ankete prikljuene lankom");

?>
